==> drd-8.x-3.0.tar.gz: drd/src/Crypt/Method/Mcrypt.php <==
<?php

/**
 * @file
 * Contains \Drupal\drd\Crypt\Method\Mcrypt.
 */

namespace Drupal\drd\Crypt\Method;

use Drupal\Core\Form\FormStateInterface;
use Drupal\drd\Crypt\BaseMethod;

/**
 * Provides MCrypt encryption functionality.
 *
 * @ingroup drd
 */
class Mcrypt extends BaseMethod {

  private $cipher;

  private $mode;

  private $iv;

  private $password;

  public function __construct($settings = array()) {
    $this->cipher = isset($settings['cipher']) ? $settings['cipher'] : 'rijndael-256';
    $this->mode = isset($settings['mode']) ? $settings['mode'] : 'cbc';
    $this->password = !empty($settings['password']) ? $settings['password'] : '';
  }

  /**
   * @inheritDoc
   */
  public function getLabel() {
    return 'MCrypt';
  }

  /**
   * @inheritDoc
   */
  public function isAvailable() {
    return function_exists('mcrypt_encrypt');
  }

  /**
   * @inheritDoc
   */
  public function getCipherMethods() {
    return array(
      'rijndael-128',
      'rijndael-192',
      'rijndael-256',
    );
  }

  public function getModes() {
    return array(
      'ecb',
      'cbc',
      'cfb',
      'ofb',
      'nofb',
      'stream',
    );
  }

  /**
   * @inheritDoc
   */
  public function settingsForm(array &$form, array $condition) {
    $form['mcrypt_cipher'] = array(
      '#type' => 'select',
      '#title' => t('Cipher'),
      '#options' => $this->getCipherMethods(),
      '#default_value' => array_search($this->cipher, $this->getCipherMethods()),
      '#states' => array(
        'required' => $condition,
      ),
    );
    $form['mcrypt_mode'] = array(
      '#type' => 'select',
      '#title' => t('Mode'),
      '#options' => $this->getModes(),
      '#default_value' => array_search($this->mode, $this->getModes()),
      '#states' => array(
        'required' => $condition,
      ),
    );
    $form['mcrypt_password'] = array(
      '#type' => 'textfield',
      '#title' => t('Password / Key'),
      '#default_value' => $this->password,
      '#states' => array(
        'required' => $condition,
      ),
    );
  }

  /**
   * @inheritDoc
   */
  public function settingsFormValues(FormStateInterface $form_state) {
    $ciphers = $this->getCipherMethods();
    $modes = $this->getModes();
    return array(
      'cipher' => $ciphers[$form_state->getValue('mcrypt_cipher')],
      'mode' => $modes[$form_state->getValue('mcrypt_mode')],
      'password' => $form_state->getValue('mcrypt_password'),
    );
  }

  /**
   * @inheritDoc
   */
  public function getIV() {
    if (empty($this->iv)) {
      $nonceSize = mcrypt_get_iv_size($this->cipher, $this->mode);
      $this->iv = mcrypt_create_iv($nonceSize);
    }
    return $this->iv;
  }

  /**
   * @inheritDoc
   */
  public function encrypt($args) {
    return mcrypt_encrypt(
      $this->cipher,
      $this->password,
      serialize($args),
      $this->mode,
      $this->getIV()
    );
  }

  /**
   * @inheritDoc
   */
  public function decrypt($body, $iv) {
    $this->iv = $iv;
    return unserialize(mcrypt_decrypt(
      $this->cipher,
      $this->password,
      $body,
      $this->mode,
      $this->iv
    ));
  }

}

==> drd-8.x-3.3.tar.gz: drd/src/Crypt/Method/Mcrypt.php <==
<?php

/**
 * @file
 * Contains \Drupal\drd\Crypt\Method\Mcrypt.
 */

namespace Drupal\drd\Crypt\Method;

use Drupal\Core\Form\FormStateInterface;
use Drupal\drd\Crypt\BaseMethod;

/**
 * Provides MCrypt encryption functionality.
 *
 * @ingroup drd
 */
class Mcrypt extends BaseMethod {

  private $cipher;

  private $mode;

  private $iv;

  private $password;

  public function __construct($settings = array()) {
    $this->cipher = isset($settings['cipher']) ? $settings['cipher'] : 'rijndael-256';
    $this->mode = isset($settings['mode']) ? $settings['mode'] : 'cbc';
    $this->password = !empty($settings['password']) ? $settings['password'] : '';
  }

  /**
   * @inheritDoc
   */
  public function getLabel() {
    return 'MCrypt';
  }

  /**
   * @inheritDoc
   */
  public function isAvailable() {
    return function_exists('mcrypt_encrypt');
  }

  /**
   * @inheritDoc
   */
  public function getCipherMethods() {
    return array(
      'rijndael-128',
      'rijndael-192',
      'rijndael-256',
    );
  }

  public function getModes() {
    return array(
      'ecb',
      'cbc',
      'cfb',
      'ofb',
      'nofb',
      'stream',
    );
  }

  /**
   * @inheritDoc
   */
  public function settingsForm(array &$form, array $condition) {
    $form['mcrypt_cipher'] = array(
      '#type' => 'select',
      '#title' => t('Cipher'),
      '#options' => $this->getCipherMethods(),
      '#default_value' => array_search($this->cipher, $this->getCipherMethods()),
      '#states' => array(
        'required' => $condition,
      ),
    );
    $form['mcrypt_mode'] = array(
      '#type' => 'select',
      '#title' => t('Mode'),
      '#options' => $this->getModes(),
      '#default_value' => array_search($this->mode, $this->getModes()),
      '#states' => array(
        'required' => $condition,
      ),
    );
  }

  /**
   * @inheritDoc
   */
  public function settingsFormValues(FormStateInterface $form_state) {
    $ciphers = $this->getCipherMethods();
    $modes = $this->getModes();

    $cipher = $ciphers[$form_state->getValue('mcrypt_cipher')];
    $mode = $modes[$form_state->getValue('mcrypt_mode')];
    $reset = (empty($this->password) ||
      $cipher != $this->cipher ||
      $mode != $this->mode);
    $this->cipher = $cipher;
    $this->mode = $mode;
    if ($reset) {
      $this->resetPassword();
    }

    return $this->getSettings();
  }

  /**
   * @inheritDoc
   */
  public function resetPassword() {
    $this->password = $this->generatePassword(mcrypt_get_key_size($this->cipher, $this->mode));
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function getSettings() {
    return array(
      'cipher' => $this->cipher,
      'mode' => $this->mode,
      'password' => $this->password,
    );
  }

  /**
   * @inheritDoc
   */
  public function getIV() {
    if (empty($this->iv)) {
      $nonceSize = mcrypt_get_iv_size($this->cipher, $this->mode);
      $this->iv = mcrypt_create_iv($nonceSize);
    }
    return $this->iv;
  }

  /**
   * @inheritDoc
   */
  public function encrypt($args) {
    return mcrypt_encrypt(
      $this->cipher,
      base64_decode($this->password),
      serialize($args),
      $this->mode,
      $this->getIV()
    );
  }

  /**
   * @inheritDoc
   */
  public function decrypt($body, $iv) {
    $this->iv = $iv;
    return unserialize(mcrypt_decrypt(
      $this->cipher,
      base64_decode($this->password),
      $body,
      $this->mode,
      $this->iv
    ));
  }

}
